@@ -23,6 +23,9 @@ FAILEDOPERATION_APIGATEWAY = 'FailedOperation.ApiGateway'
 # 创建触发器失败。
 FAILEDOPERATION_APIGW = 'FailedOperation.Apigw'
 
+# 获取Apm InstanceId失败。
+FAILEDOPERATION_APMCONFIGINSTANCEID = 'FailedOperation.ApmConfigInstanceId'
+
 # 当前异步事件状态不支持此操作，请稍后重试。
 FAILEDOPERATION_ASYNCEVENTSTATUS = 'FailedOperation.AsyncEventStatus'
 
@@ -98,6 +101,12 @@ FAILEDOPERATION_OPENSERVICE = 'FailedOperation.OpenService'
 # 操作冲突。
 FAILEDOPERATION_OPERATIONCONFLICT = 'FailedOperation.OperationConflict'
 
+# 创建定时预置任务失败。
+FAILEDOPERATION_PROVISIONCREATETIMER = 'FailedOperation.ProvisionCreateTimer'
+
+# 删除定时预置任务失败。
+FAILEDOPERATION_PROVISIONDELETETIMER = 'FailedOperation.ProvisionDeleteTimer'
+
 # 当前函数版本已有预置任务处于进行中，请稍后重试。
 FAILEDOPERATION_PROVISIONEDINPROGRESS = 'FailedOperation.ProvisionedInProgress'
 
@@ -113,6 +122,9 @@ FAILEDOPERATION_QCSROLENOTFOUND = 'FailedOperation.QcsRoleNotFound'
 # 当前函数已有保留并发设置任务处于进行中，请稍后重试。
 FAILEDOPERATION_RESERVEDINPROGRESS = 'FailedOperation.ReservedInProgress'
 
+# Topic不存在。
+FAILEDOPERATION_TOPICNOTEXIST = 'FailedOperation.TopicNotExist'
+
 # 用户并发内存配额设置任务处于进行中，请稍后重试。
 FAILEDOPERATION_TOTALCONCURRENCYMEMORYINPROGRESS = 'FailedOperation.TotalConcurrencyMemoryInProgress'
 
@@ -176,9 +188,24 @@ INVALIDPARAMETERVALUE_ACTION = 'InvalidParameterValue.Action'
 # AdditionalVersionWeights参数传入错误。
 INVALIDPARAMETERVALUE_ADDITIONALVERSIONWEIGHTS = 'InvalidParameterValue.AdditionalVersionWeights'
 
+# 不支持删除默认别名，请修正后重试。
+INVALIDPARAMETERVALUE_ALIAS = 'InvalidParameterValue.Alias'
+
 # ApiGateway参数错误。
 INVALIDPARAMETERVALUE_APIGATEWAY = 'InvalidParameterValue.ApiGateway'
 
+# ApmConfig参数传入错误。
+INVALIDPARAMETERVALUE_APMCONFIG = 'InvalidParameterValue.ApmConfig'
+
+# ApmConfigInstanceId参数传入错误。
+INVALIDPARAMETERVALUE_APMCONFIGINSTANCEID = 'InvalidParameterValue.ApmConfigInstanceId'
+
+# ApmConfigRegion参数传入错误。
+INVALIDPARAMETERVALUE_APMCONFIGREGION = 'InvalidParameterValue.ApmConfigRegion'
+
+# Args 参数值有误。
+INVALIDPARAMETERVALUE_ARGS = 'InvalidParameterValue.Args'
+
 # 函数异步重试配置参数无效。
 INVALIDPARAMETERVALUE_ASYNCTRIGGERCONFIG = 'InvalidParameterValue.AsyncTriggerConfig'
 
@@ -191,9 +218,6 @@ INVALIDPARAMETERVALUE_CFSPARAMETERDUPLICATE = 'InvalidParameterValue.CfsParamete
 # cfs配置项取值与规范不符。
 INVALIDPARAMETERVALUE_CFSPARAMETERERROR = 'InvalidParameterValue.CfsParameterError'
 
-# cfs参数格式与规范不符。
-INVALIDPARAMETERVALUE_CFSSTRUCTIONERROR = 'InvalidParameterValue.CfsStructionError'
-
 # Ckafka传入错误。
 INVALIDPARAMETERVALUE_CKAFKA = 'InvalidParameterValue.Ckafka'
 
@@ -215,6 +239,9 @@ INVALIDPARAMETERVALUE_CODESECRET = 'InvalidParameterValue.CodeSecret'
 # CodeSource传入错误。
 INVALIDPARAMETERVALUE_CODESOURCE = 'InvalidParameterValue.CodeSource'
 
+# Command[Entrypoint] 参数值有误。
+INVALIDPARAMETERVALUE_COMMAND = 'InvalidParameterValue.Command'
+
 # CompatibleRuntimes参数传入错误。
 INVALIDPARAMETERVALUE_COMPATIBLERUNTIMES = 'InvalidParameterValue.CompatibleRuntimes'
 
@@ -248,6 +275,9 @@ INVALIDPARAMETERVALUE_DEFAULTNAMESPACE = 'InvalidParameterValue.DefaultNamespace
 # Description传入错误。
 INVALIDPARAMETERVALUE_DESCRIPTION = 'InvalidParameterValue.Description'
 
+# 环境变量DNS[OS_NAMESERVER]配置有误。
+INVALIDPARAMETERVALUE_DNSINFO = 'InvalidParameterValue.DnsInfo'
+
 # EipConfig参数错误。
 INVALIDPARAMETERVALUE_EIPCONFIG = 'InvalidParameterValue.EipConfig'
 
@@ -266,6 +296,9 @@ INVALIDPARAMETERVALUE_ENVIRONMENTSYSTEMPROTECT = 'InvalidParameterValue.Environm
 # Filters参数错误。
 INVALIDPARAMETERVALUE_FILTERS = 'InvalidParameterValue.Filters'
 
+# Function取值与规范不符，请修正后再试。可参考：https://tencentcs.com/5jXKFnBW。
+INVALIDPARAMETERVALUE_FUNCTION = 'InvalidParameterValue.Function'
+
 # 函数不存在。
 INVALIDPARAMETERVALUE_FUNCTIONNAME = 'InvalidParameterValue.FunctionName'
 
@@ -290,6 +323,12 @@ INVALIDPARAMETERVALUE_GITUSERNAME = 'InvalidParameterValue.GitUserName'
 # Handler传入错误。
 INVALIDPARAMETERVALUE_HANDLER = 'InvalidParameterValue.Handler'
 
+# IdleTimeOut参数传入错误。
+INVALIDPARAMETERVALUE_IDLETIMEOUT = 'InvalidParameterValue.IdleTimeOut'
+
+# imageUri 传入有误。
+INVALIDPARAMETERVALUE_IMAGEURI = 'InvalidParameterValue.ImageUri'
+
 # InlineZipFile非法。
 INVALIDPARAMETERVALUE_INLINEZIPFILE = 'InvalidParameterValue.InlineZipFile'
 
@@ -335,12 +374,30 @@ INVALIDPARAMETERVALUE_ORDERBY = 'InvalidParameterValue.OrderBy'
 # 入参不是标准的json。
 INVALIDPARAMETERVALUE_PARAM = 'InvalidParameterValue.Param'
 
+# ProtocolType参数传入错误。
+INVALIDPARAMETERVALUE_PROTOCOLTYPE = 'InvalidParameterValue.ProtocolType'
+
+# 定时预置的cron配置重复。
+INVALIDPARAMETERVALUE_PROVISIONTRIGGERCRONCONFIGDUPLICATE = 'InvalidParameterValue.ProvisionTriggerCronConfigDuplicate'
+
+# TriggerName参数传入错误。
+INVALIDPARAMETERVALUE_PROVISIONTRIGGERNAME = 'InvalidParameterValue.ProvisionTriggerName'
+
+# TriggerName重复。
+INVALIDPARAMETERVALUE_PROVISIONTRIGGERNAMEDUPLICATE = 'InvalidParameterValue.ProvisionTriggerNameDuplicate'
+
+# ProvisionType 参数传入错误。
+INVALIDPARAMETERVALUE_PROVISIONTYPE = 'InvalidParameterValue.ProvisionType'
+
 # PublicNetConfig参数错误。
 INVALIDPARAMETERVALUE_PUBLICNETCONFIG = 'InvalidParameterValue.PublicNetConfig'
 
 # 不支持的函数版本。
 INVALIDPARAMETERVALUE_QUALIFIER = 'InvalidParameterValue.Qualifier'
 
+# 企业版镜像实例ID[RegistryId]传值错误。
+INVALIDPARAMETERVALUE_REGISTRYID = 'InvalidParameterValue.RegistryId'
+
 # RetCode不合法。
 INVALIDPARAMETERVALUE_RETCODE = 'InvalidParameterValue.RetCode'
 
@@ -353,12 +410,18 @@ INVALIDPARAMETERVALUE_RUNTIME = 'InvalidParameterValue.Runtime'
 # searchkey 不是 Keyword,Tag 或者 Runtime。
 INVALIDPARAMETERVALUE_SEARCHKEY = 'InvalidParameterValue.SearchKey'
 
+# SecretInfo错误。
+INVALIDPARAMETERVALUE_SECRETINFO = 'InvalidParameterValue.SecretInfo'
+
 # ServiceName命名不规范。
 INVALIDPARAMETERVALUE_SERVICENAME = 'InvalidParameterValue.ServiceName'
 
 # Stamp取值与规范不符，请修正后再试。
 INVALIDPARAMETERVALUE_STAMP = 'InvalidParameterValue.Stamp'
 
+# 起始时间传入错误。
+INVALIDPARAMETERVALUE_STARTTIME = 'InvalidParameterValue.StartTime'
+
 # 需要同时指定开始日期与结束日期。
 INVALIDPARAMETERVALUE_STARTTIMEORENDTIME = 'InvalidParameterValue.StartTimeOrEndTime'
 
@@ -374,18 +437,30 @@ INVALIDPARAMETERVALUE_TEMPCOSOBJECTNAME = 'InvalidParameterValue.TempCosObjectNa
 # TraceEnable取值与规范不符，请修正后再试。
 INVALIDPARAMETERVALUE_TRACEENABLE = 'InvalidParameterValue.TraceEnable'
 
+# TriggerCronConfig参数传入错误。
+INVALIDPARAMETERVALUE_TRIGGERCRONCONFIG = 'InvalidParameterValue.TriggerCronConfig'
+
+# TriggerCronConfig参数定时触发间隔小于指定值。
+INVALIDPARAMETERVALUE_TRIGGERCRONCONFIGTIMEINTERVAL = 'InvalidParameterValue.TriggerCronConfigTimeInterval'
+
 # TriggerDesc传入参数错误。
 INVALIDPARAMETERVALUE_TRIGGERDESC = 'InvalidParameterValue.TriggerDesc'
 
 # TriggerName传入错误。
 INVALIDPARAMETERVALUE_TRIGGERNAME = 'InvalidParameterValue.TriggerName'
 
+# TriggerProvisionedConcurrencyNum参数传入错误。
+INVALIDPARAMETERVALUE_TRIGGERPROVISIONEDCONCURRENCYNUM = 'InvalidParameterValue.TriggerProvisionedConcurrencyNum'
+
 # Type传入错误。
 INVALIDPARAMETERVALUE_TYPE = 'InvalidParameterValue.Type'
 
 # 开启cfs配置的同时必须开启vpc。
 INVALIDPARAMETERVALUE_VPCNOTSETWHENOPENCFS = 'InvalidParameterValue.VpcNotSetWhenOpenCfs'
 
+# WebSocketsParams参数传入错误。
+INVALIDPARAMETERVALUE_WEBSOCKETSPARAMS = 'InvalidParameterValue.WebSocketsParams'
+
 # 检测到不是标准的zip文件，请重新压缩后再试。
 INVALIDPARAMETERVALUE_ZIPFILE = 'InvalidParameterValue.ZipFile'
 
@@ -440,6 +515,12 @@ LIMITEXCEEDED_NAMESPACE = 'LimitExceeded.Namespace'
 # Offset超出限制。
 LIMITEXCEEDED_OFFSET = 'LimitExceeded.Offset'
 
+# 定时预置数量超过最大限制。
+LIMITEXCEEDED_PROVISIONTRIGGERACTION = 'LimitExceeded.ProvisionTriggerAction'
+
+# 定时触发间隔小于最大限制。
+LIMITEXCEEDED_PROVISIONTRIGGERINTERVAL = 'LimitExceeded.ProvisionTriggerInterval'
+
 # 函数异步重试配置异步重试次数超过限制。
 LIMITEXCEEDED_RETRYNUM = 'LimitExceeded.RetryNum'
 
@@ -515,6 +596,9 @@ RESOURCENOTFOUND_CDN = 'ResourceNotFound.Cdn'
 # 指定的cfs下未找到您所指定的挂载点。
 RESOURCENOTFOUND_CFSMOUNTINSNOTMATCH = 'ResourceNotFound.CfsMountInsNotMatch'
 
+# 检测cfs状态为不可用。
+RESOURCENOTFOUND_CFSSTATUSERROR = 'ResourceNotFound.CfsStatusError'
+
 # cfs与云函数所处vpc不一致。
 RESOURCENOTFOUND_CFSVPCNOTMATCH = 'ResourceNotFound.CfsVpcNotMatch'
 
@@ -545,6 +629,9 @@ RESOURCENOTFOUND_GETCFSMOUNTINSERROR = 'ResourceNotFound.GetCfsMountInsError'
 # 获取cfs信息错误。
 RESOURCENOTFOUND_GETCFSNOTMATCH = 'ResourceNotFound.GetCfsNotMatch'
 
+# 未找到指定的ImageConfig，请创建后再试。
+RESOURCENOTFOUND_IMAGECONFIG = 'ResourceNotFound.ImageConfig'
+
 # layer不存在。
 RESOURCENOTFOUND_LAYER = 'ResourceNotFound.Layer'
 
@@ -560,6 +647,9 @@ RESOURCENOTFOUND_QUALIFIER = 'ResourceNotFound.Qualifier'
 # 角色不存在。
 RESOURCENOTFOUND_ROLE = 'ResourceNotFound.Role'
 
+# Role不存在。
+RESOURCENOTFOUND_ROLECHECK = 'ResourceNotFound.RoleCheck'
+
 # Timer不存在。
 RESOURCENOTFOUND_TIMER = 'ResourceNotFound.Timer'
 
@@ -626,8 +716,14 @@ UNSUPPORTEDOPERATION_CDN = 'UnsupportedOperation.Cdn'
 # Cos操作不支持。
 UNSUPPORTEDOPERATION_COS = 'UnsupportedOperation.Cos'
 
+# 指定的配置EipFixed暂不支持。
+UNSUPPORTEDOPERATION_EIPFIXED = 'UnsupportedOperation.EipFixed'
+
 # 不支持此地域。
 UNSUPPORTEDOPERATION_REGION = 'UnsupportedOperation.Region'
 
 # Trigger操作不支持。
 UNSUPPORTEDOPERATION_TRIGGER = 'UnsupportedOperation.Trigger'
+
+# 指定的配置VpcConfig暂不支持。
+UNSUPPORTEDOPERATION_VPCCONFIG = 'UnsupportedOperation.VpcConfig'
